/*
 * Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
 *
 * This file is part of NRAO Workspaces.
 *
 * Workspaces is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Workspaces is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"flag"
	"fmt"
	"ssa/seci_ingestion_status/pkg/inspect"
	"ssa/seci_ingestion_status/pkg/wf_info"
)

func main() {
	var wf_req_id string
	var capo_profile string

	flag.StringVar(&wf_req_id, "id", "", "Workflow Request Id of SECI Ingestion to inspect")
	flag.StringVar(&capo_profile, "prop", "/home/casa/capo/${CAPO_PROFILE}.properties", "Path to the CAPO properties file")

	flag.Parse()

	// Make sure a wf_req_id was provided
	if len(wf_req_id) == 0 {
		flag.Usage()
		return
	}

	seci_wf := wf_info.GetSECIWorkflowInfo(wf_req_id, capo_profile)
	status_msg := inspect.InspectSECIIngestionStatus(seci_wf)
	fmt.Println(status_msg)
}
